
Welcome to pygeoid's documentation!
===================================

.. include:: ../README.rst

.. toctree::
  :maxdepth: 2
  :hidden:
  :caption: Getting Started

  install.rst

.. toctree::
  :maxdepth: 2
  :hidden:
  :caption: User Guide

.. toctree::
  :maxdepth: 2
  :hidden:
  :caption: Reference Guide

  api/index.rst

.. toctree::
  :maxdepth: 1
  :caption: Developer
  

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
